@echo off
rem #
rem # Licensed Materials - Property of IBM and/or HCL Confidential
rem # Rational ClearQuest 
rem # (C) Copyright IBM Corp. 2010, 2016.  All Rights Reserved.
rem # (C) Copyright HCL Technologies Ltd. 2017.  All Rights Reserved.
rem # US Government Users Restricted Rights -
rem # Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem #
rem # The source code for this program is not published or otherwise
rem # divested of its trade secrets, irrespective of what has been
rem # deposited with the U.S. Copyright Office.
rem #
rem # Run this batch file to copy the Eclipse plugins of the reporting driver from the shared Installation
rem # Manager directory to a target directory
rem # Usage:   
rem #	copyDriverPlugins <no arguments>   - Copies the ClearQuest driver plugins to the current directory
rem #	copyDriverPlugins <targetDirectory> - Copies the ClearQuest driver plugins to the targetDirectory   
rem #	copyDriverPlugins clean - Removes existing ClearQuest driver plugins and jar files.  When this option is used, 
rem #   	the current directory is treated as the targetDirectory. 

setlocal
:start
rem PLUGIN_PATH and EXTRACT_PROGRAM path can be changed if necessary.  Other settings should not be changed.
set PLUGIN_PATH=%CLEARQUEST_HOME%\reports\driver\plugins
set EXTRACT_PROGRAM="%RATIONAL_COMMON%\infozip\unzip"

set CQ_CORE_LIB=com.ibm.rational.clearquest.core.lib
set CQ_JDBC=com.ibm.rational.clearquest.jdbc
set CM_LIBRARY=com.ibm.rational.stp
set ODA_JDBC=com.ibm.rational.clearquest.oda.jdbc_
set ODA_JDBC_NL=com.ibm.rational.clearquest.oda.jdbc.nl1

set BIRT_3_RUNTIME=org.eclipse.birt.runtime_3
set BIRT_4_RUNTIME=org.eclipse.birt.runtime_4
set BIRT_VER_FOUND=
set BIRT_RUNTIME_FOUND=


if "clean" == "%1" goto clean

if [%1]==[] goto setdefault
set TARGET_PATH=%1
set BIRT_PATH=%~1
call :detectBIRTruntimeVersion %TARGET_PATH%
goto copyPlugins

:setdefault
set TARGET_PATH=.
set BIRT_PATH=%cd%
call :detectBIRTruntimeVersion %TARGET_PATH%
goto copyPlugins

:cleanForUpdate
if not [%2]==[] set TARGET_PATH=%2
call :detectBIRTruntimeVersion %TARGET_PATH%
goto :cleanJ2EE
@echo Complete the cleanup.
goto:eof

:clean
if not [%2]==[] goto cleanForUpdate
set TARGET_PATH=.
call :detectBIRTruntimeVersion %TARGET_PATH%
if /i (%cd:~-3%)==(lib) goto cleanJ2EE
goto :cleanOSGi


:cleanJ2EE
@echo Removing ClearQuest Reporting Driver JAR
erase %TARGET_PATH%\stpcmmn.jar
erase %TARGET_PATH%\stpwvcm.jar
erase %TARGET_PATH%\stpcq.jar
erase %TARGET_PATH%\cqjni.jar
erase %TARGET_PATH%\commons-codec-1.3.jar
erase %TARGET_PATH%\commons-httpclient-3.0.1.jar
erase %TARGET_PATH%\commons-codec-1.10.jar
erase %TARGET_PATH%\httpclient-4.5.2.jar
erase %TARGET_PATH%\httpmime-4.5.2.jar
erase %TARGET_PATH%\httpcore-4.4.4.jar
erase %TARGET_PATH%\com.ibm.rational.clearquest*.jar

if %BIRT_VER_FOUND% GEQ 4 goto skipRenameForCleanJ2EE

rem JAR renames is done for BIRT 3 or ealier only.
@echo Renaming axis.jar.backup back to axis.jar
@echo Renaming org.apache.xml.serializer_version.jar.backup to org.apache.xml.serializer_version.jar
@echo Renaming org.apache.xerces_version.jar to org.apache.xerces_version.jar.backup
rename %TARGET_PATH%\*.jar.backup *.
:skipRenameForCleanJ2EE
@echo Complete the cleanup J2EE.
goto:eof

:cleanOSGi
@echo Removing ClearQuest Reporting Driver plugins

FOR /D /R %cd% %%X IN (%CQ_CORE_LIB%* %CQ_JDBC%* %CM_LIBRARY%* %CQ_JDBC%* %ODA_JDBC_NL%*) DO RD /S /Q "%%X"
del com.ibm.rational.clearquest* /Q
@echo Complete the cleanup OSGi.
goto:eof

rem Get the newest version of the passed plugin, and copy to the TARGET_PATH
:copyNewest
call :getNewest %1
@echo Copying %PLUGIN_PATH%\%NEWEST_FILE%
if NOT (%NEWEST_FILE%)==() copy %PLUGIN_PATH%\%NEWEST_FILE% %TARGET_PATH%
goto:eof


:copyPlugins
rem Determine if the copy target is \WEB-INF\lib.  If so, assume BIRT deployment uses standard J2EE configuration
if /i (%BIRT_PATH:~-3%)==(lib) goto copyPluginsJ2EE
if /i (%BIRT_PATH:~-4%)==(lib/) goto copyPluginsJ2EE
if /i (%BIRT_PATH:~-4%)==(lib\) goto copyPluginsJ2EE
goto copyPluginsOSGi


:copyPluginsOSGi
@echo Copying ClearQuest Reporting Driver files to OSGi directory %BIRT_PATH%

copy "%PLUGIN_PATH%\%CQ_CORE_LIB%*.jar" %TARGET_PATH%
copy "%PLUGIN_PATH%\%CQ_JDBC%*.jar" %TARGET_PATH%
copy "%PLUGIN_PATH%\%CM_LIBRARY%*.jar" %TARGET_PATH%
copy "%PLUGIN_PATH%\%ODA_JDBC%*.jar" %TARGET_PATH%
copy "%PLUGIN_PATH%\%ODA_JDBC_NL%*.jar" %TARGET_PATH%
goto:eof

:copyPluginsJ2EE
@echo Copying ClearQuest Reporting Driver files to J2EE lib directory %BIRT_PATH%
@echo Copying stpcmmn.jar,stpwvcm.jar,stpcq.jar and cqjni.jar
copy "%RATIONAL_COMMON%\stpcmmn.jar" %TARGET_PATH%
copy "%RATIONAL_COMMON%\stpwvcm.jar" %TARGET_PATH%
copy "%RATIONAL_COMMON%\stpcq.jar" %TARGET_PATH%
copy "%CLEARQUEST_HOME%\cqjni.jar" %TARGET_PATH%

copy "%PLUGIN_PATH%\%CQ_JDBC%*.jar" %TARGET_PATH%
copy "%PLUGIN_PATH%\%ODA_JDBC%*.jar" %TARGET_PATH%
copy "%PLUGIN_PATH%\%ODA_JDBC_NL%*.jar" %TARGET_PATH%

%EXTRACT_PROGRAM% "%PLUGIN_PATH%\%CM_LIBRARY%*.jar" commons-codec-1.10.jar -d %TARGET_PATH% 
%EXTRACT_PROGRAM% "%PLUGIN_PATH%\%CM_LIBRARY%*.jar" httpclient-4.5.2.jar -d %TARGET_PATH% 
%EXTRACT_PROGRAM% "%PLUGIN_PATH%\%CM_LIBRARY%*.jar" httpmime-4.5.2.jar -d %TARGET_PATH% 
%EXTRACT_PROGRAM% "%PLUGIN_PATH%\%CM_LIBRARY%*.jar" httpcore-4.4.4.jar -d %TARGET_PATH% 

if %BIRT_VER_FOUND% GEQ 4 goto skipRenameForCopyPluginsJ2EE

rem JAR renames is done for BIRT 3 or ealier only.
@echo Renaming axis.jar to axis.jar.backup
rename %TARGET_PATH%\axis.jar axis.jar.backup

@echo Renaming org.apache.xml.serializer.jar to org.apache.xml.serializer.jar.backup
set NEWEST_FILE=
call :getNewest %TARGET_PATH%\org.apache.xml.serializer_*.jar
if not (%NEWEST_FILE%)==() rename %TARGET_PATH%\%NEWEST_FILE% %NEWEST_FILE%.backup

@echo Renaming org.apache.xerces_*.jar to org.apache.xerces_*.jar.backup
set NEWEST_FILE=
call :getNewest %TARGET_PATH%\org.apache.xerces_*.jar
if not (%NEWEST_FILE%)==() rename %TARGET_PATH%\%NEWEST_FILE% %NEWEST_FILE%.backup
:skipRenameForCopyPluginsJ2EE
goto:eof

rem Set variable NEWEST_FILE to the newest version of the passed plugin
:getNewest
FOR /F "delims=" %%I IN ('DIR %1 /B /O:-D') DO set "NEWEST_FILE=%%I"
goto :eof

rem Figures out and sets the BIRT version in use.
:detectBIRTruntimeVersion
if not [%CQ_BIRT_VERSION%]==[] (
   set BIRT_VER_FOUND=%CQ_BIRT_VERSION%
   @echo Using custom provided BIRT version: %BIRT_VER_FOUND%
   goto:eof
)
call :findBIRTruntimeFile %1\%BIRT_3_RUNTIME%*.jar
if not "%BIRT_RUNTIME_FOUND%"=="" (
   set BIRT_VER_FOUND=3
   goto:doneDetectBIRTruntimeVersion
)
call :findBIRTruntimeFile %1\%BIRT_4_RUNTIME%*.jar
if not "%BIRT_RUNTIME_FOUND%"=="" (
   set BIRT_VER_FOUND=4
   goto:doneDetectBIRTruntimeVersion
)
:doneDetectBIRTruntimeVersion
if not "%BIRT_VER_FOUND%"=="" (
   @echo Found BIRT runtime version: %BIRT_VER_FOUND%
) else (
   set BIRT_VER_FOUND=4
   @echo WARNING: Cannot detect BIRT version, assuming version 4.x.
   @echo          If you know the version of BIRT and want to force it, set the
   @echo          environment variable 'CQ_BIRT_VERSION' to the major version of
   @echo          BIRT such as: CQ_BIRT_VERSION=3 or CQ_BIRT_VERSION=4.
)
goto:eof

rem Looks for and set the BIRT runtime JAR file name.
:findBIRTruntimeFile
for /F "delims=" %%I IN ('DIR %1 /B /O:-D') DO set "BIRT_RUNTIME_FOUND=%%I"
goto:eof


endlocal
